package com.bweb.controller.goods;

import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.SessionObject;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.GoodsBrand;
import com.hfkj.model.GoodsBrandModel;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.service.goods.GoodsBrandService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping(value="/goodsBrand")
@Api(value="商品品牌")
public class GoodsBrandController {
    private static final Logger log = LoggerFactory.getLogger(GoodsBrandController.class);

    @Resource
    private GoodsBrandService goodsBrandService;

    @Resource
    private UserCenter userCenter;

    @RequestMapping(value="/editGoodsBrand",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "编辑商品类型")
    public ResponseData editGoodsBrand(@RequestBody GoodsBrand body, HttpServletRequest request) {

        SessionObject sessionObject = userCenter.getSessionObject(request);
        SecUserSessionObject userModel = (SecUserSessionObject) sessionObject.getObject();

        if (body == null
                || body.getImgUrl() == null
                || StringUtils.isBlank(body.getTitle())) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
        }

        GoodsBrand GoodsBrand;

        if (body.getId() != null) {
            // 查询商品类型
            GoodsBrand = goodsBrandService.queryDetail(body.getId());
            if (GoodsBrand == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
        } else {
            GoodsBrand = new GoodsBrand();
            GoodsBrand.setCreateTime(new Date());
        }

        GoodsBrand.setUpdateTime(new Date());
        GoodsBrand.setStatus(1);
        GoodsBrand.setTitle(body.getTitle());
        GoodsBrand.setParentId(body.getParentId());
        GoodsBrand.setBusinessType(body.getBusinessType());
        GoodsBrand.setImgUrl(body.getImgUrl());
        GoodsBrand.setOpId(userModel.getAccount().getId());
        GoodsBrand.setOpName(userModel.getAccount().getUserName());

        if (body.getId() != null) {
            GoodsBrandService.update(GoodsBrand);
        } else {
            GoodsBrandService.create(GoodsBrand);
        }

        return ResponseMsgUtil.success("操作成功");
    }

    @RequestMapping(value="/getList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询列表")
    public ResponseData getList() {
        try {


            List<GoodsBrand> list = GoodsBrandService.getList(new HashMap<>());

            List<GoodsBrandModel> GoodsBrandModels = GoodsBrandService.getGoodsBrandModelList(list);


            return ResponseMsgUtil.success(GoodsBrandModels);

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/delete",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "删除")
    public ResponseData delete(@RequestParam(value = "id" , required = false) Long id) {
        try {

            Map<String , Object> map = new HashMap<>();
            map.put("parentId" , id);
            List<GoodsBrand> list = GoodsBrandService.getList(map);

            if (!list.isEmpty()) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "存在下级分类，不可删除！");
            }

            GoodsBrandService.delete(id , false);

            return ResponseMsgUtil.success("删除成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
